{ stdenv, lib, fetchzip, fetchurl, fetchedGitPrivate, sassc }:
let
  chloe = { config }: rec {
    environment = config.environment;
    phpFpm = rec {
      socket = "/var/run/phpfpm/chloe-${environment}.sock";
      pool = ''
        listen = ${socket}
        user = ${apache.user}
        group = ${apache.group}
        listen.owner = ${apache.user}
        listen.group = ${apache.group}
        php_admin_value[upload_max_filesize] = 20M
        php_admin_value[post_max_size] = 20M
        ;php_admin_flag[log_errors] = on
        php_admin_value[open_basedir] = "${../commons/spip/spip_mes_options.php}:${configDir}:${webRoot}:${varDir}:/tmp"
        php_admin_value[session.save_path] = "${varDir}/phpSessions"
        env[SPIP_CONFIG_DIR] = "${configDir}"
        env[SPIP_VAR_DIR] = "${varDir}"
        env[SPIP_SITE] = "chloe-${environment}"
        env[SPIP_LDAP_BASE] = "dc=immae,dc=eu"
        env[SPIP_LDAP_HOST] = "ldaps://ldap.immae.eu"
        env[SPIP_LDAP_SEARCH_DN] = "${config.ldap.dn}"
        env[SPIP_LDAP_SEARCH_PW] = "${config.ldap.password}"
        env[SPIP_LDAP_SEARCH] = "${config.ldap.search}"
        env[SPIP_MYSQL_HOST] = "${config.mysql.host}"
        env[SPIP_MYSQL_PORT] = "${config.mysql.port}"
        env[SPIP_MYSQL_DB] = "${config.mysql.name}"
        env[SPIP_MYSQL_USER] = "${config.mysql.user}"
        env[SPIP_MYSQL_PASSWORD] = "${config.mysql.password}"
        ${if environment == "dev" then ''
        pm = ondemand
        pm.max_children = 5
        pm.process_idle_timeout = 60
        '' else ''
        pm = dynamic
        pm.max_children = 20
        pm.start_servers = 2
        pm.min_spare_servers = 1
        pm.max_spare_servers = 3
        ''}'';
    };
    apache = rec {
      user = "wwwrun";
      group = "wwwrun";
      modules = [ "proxy_fcgi" ];
      webappName = "chloe_${environment}";
      root = "/run/current-system/webapps/${webappName}";
      vhostConf = ''
        RewriteEngine On
        ${if environment == "prod" then ''
        RewriteRule ^/news.rss  /spip.php?page=backend&id_rubrique=1
        '' else ""}

        <FilesMatch "\.php$">
          SetHandler "proxy:unix:${phpFpm.socket}|fcgi://localhost"
        </FilesMatch>

        <Directory ${root}>
          DirectoryIndex index.php index.htm index.html
          Options -Indexes +FollowSymLinks +MultiViews +Includes
          Include ${root}/htaccess.txt

          AllowOverride AuthConfig FileInfo Limit
          Require all granted
        </Directory>

        <DirectoryMatch "${root}/squelettes">
          Require all denied
        </DirectoryMatch>

        <FilesMatch "(.htaccess|rewrite-rules|.gitignore)$">
          Require all denied
        </FilesMatch>

        ${if environment == "dev" then ''
        <Location />
          Use LDAPConnect
          Require ldap-group cn=chloe.immae.eu,cn=httpd,ou=services,dc=immae,dc=eu
          ErrorDocument 401 "<html><meta http-equiv=\"refresh\" content=\"0;url=https://osteopathe-cc.fr\"></html>"
        </Location>
        '' else ''
        Use Stats osteopathe-cc.fr
        ''}
        '';
    };
    activationScript = {
      deps = [ "wrappers" ];
      text = ''
        install -m 0755 -o ${apache.user} -g ${apache.group} -d ${varDir} ${varDir}/IMG ${varDir}/tmp ${varDir}/local
        install -m 0750 -o ${apache.user} -g ${apache.group} -d ${varDir}/phpSessions
      '';
    };
    configDir = ./chloe_config_ + environment;
    varDir = "/var/lib/chloe_${environment}";
    siteDir = stdenv.mkDerivation (fetchedGitPrivate ./chloe.json // rec {
      buildPhase = ''
        make
        '';
      installPhase = ''
        cp -a . $out
        '';
      buildInputs = [ sassc ];
    });
    webRoot = stdenv.mkDerivation rec {
      name = "chloe-${environment}-spip-${version}";
      version = "3.2.3";
      src = fetchzip {
        url = "https://files.spip.net/spip/archives/SPIP-v${version}.zip";
        sha256 = "1r1mjvsnrp6mvkgjakvi3x4ms8m8k5mp93micbbg8r99fj7qlfkq";
      };
      paches = [ ../commons/spip/spip_ldap_patch.patch ];
      buildPhase = ''
        rm -rf IMG local tmp config/remove.txt
        ln -sf ${../commons/spip/spip_mes_options.php} config/mes_options.php
        echo "Require all denied" > "config/.htaccess"
        ln -sf ${varDir}/{IMG,local} .
      '';
      installPhase = ''
        cp -a . $out
        cp -a ${siteDir}/* $out
      '';
    };
  };
in
  chloe
